pub struct ChannelMessage {
pub meta: Option<MessageMeta>,
pub channel: SubscriptionChannel,
pub body: Option<Value>,
}Fields
meta: Option<MessageMeta>channel: SubscriptionChannelbody: Option<Value>Trait Implementations
Sourceimpl Debug for ChannelMessage
impl Debug for ChannelMessage
Sourceimpl<'de> Deserialize<'de> for ChannelMessage
impl<'de> Deserialize<'de> for ChannelMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromRedisValue for ChannelMessage
impl FromRedisValue for ChannelMessage
Sourcefn from_redis_value(v: &Value) -> RedisResult<Self>
fn from_redis_value(v: &Value) -> RedisResult<Self>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
fn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
fn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
Similar to
from_redis_value but constructs a vector of objects
from another vector of values. This primarily exists internally
to customize the behavior for vectors of tuples.Sourcefn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
fn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
The same as
from_redis_values, but takes a Vec<Value> instead
of a &[Value].Sourcefn from_each_owned_redis_values(
items: Vec<Value>,
) -> Vec<Result<Self, RedisError>>
fn from_each_owned_redis_values( items: Vec<Value>, ) -> Vec<Result<Self, RedisError>>
The same as
from_owned_redis_values, but returns a result for each
conversion to make handling them case-by-case possible.Sourcefn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
fn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
Convert bytes to a single element vector.
Sourceimpl PartialEq for ChannelMessage
impl PartialEq for ChannelMessage
Sourceimpl Serialize for ChannelMessage
impl Serialize for ChannelMessage
Sourceimpl ToRedisArgs for ChannelMessage
impl ToRedisArgs for ChannelMessage
Sourcefn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
fn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
This writes the value into a vector of bytes. Each item
is a single argument. Most items generate a single item. Read more
Sourcefn to_redis_args(&self) -> Vec<Vec<u8>>
fn to_redis_args(&self) -> Vec<Vec<u8>>
This converts the value into a vector of bytes. Each item
is a single argument. Most items generate a vector of a
single item. Read more
Sourcefn describe_numeric_behavior(&self) -> NumericBehavior
fn describe_numeric_behavior(&self) -> NumericBehavior
Returns an information about the contained value with regards
to it’s numeric behavior in a redis context. This is used in
some high level concepts to switch between different implementations
of redis functions (for instance
INCR vs INCRBYFLOAT).Sourcefn num_of_args(&self) -> usize
fn num_of_args(&self) -> usize
Returns the number of arguments this value will generate. Read more
impl StructuralPartialEq for ChannelMessage